AppTheme class

Constructors

AppTheme()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

backColor Color
no setter
backgroundColor Color
no setter
isLightMode bool
getter/setter pair
primaryTextColor Color
no setter
redErrorColor Color
no setter
scaffoldBackgroundColor Color
no setter
secondaryTextColor Color
no setter
whiteColor Color
no setter