ApiService class

Constructors

ApiService()
factory

Properties

failedMap Map<String, dynamic>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMethodCall({required String api, required Function fun}) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postMethodCall({required String api, dynamic json, required Function fun}) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

dio ↔ Dio
getter/setter pair