ClassicalConfig class

Constructors

ClassicalConfig({String? usernameVariable, String? passwordVariable, String? sId, String? createdTime, String? updatedTime, UsernameVariableMetadata? usernameVariableMetadata, PasswordVariableMetadata? passwordVariableMetadata, String? id})
ClassicalConfig.fromJson(Map<String, dynamic> json)

Properties

createdTime String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
passwordVariable String?
getter/setter pair
passwordVariableMetadata PasswordVariableMetadata?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sId String?
getter/setter pair
updatedTime String?
getter/setter pair
usernameVariable String?
getter/setter pair
usernameVariableMetadata UsernameVariableMetadata?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited