Data class
Constructors
-
Data({String? clientId, bool? enableClassical, List<
String> ? allowedUsernameTypes, DisplaySettings? displaySettings, Settings? settings, List<LoginProviders> ? loginProviders}) -
Data.fromJson(Map<
String, dynamic> json)
Properties
-
allowedUsernameTypes
↔ List<
String> ? -
getter/setter pair
- clientId ↔ String?
-
getter/setter pair
- displaySettings ↔ DisplaySettings?
-
getter/setter pair
- enableClassical ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
loginProviders
↔ List<
LoginProviders> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings ↔ Settings?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited