LoginProviders class

Constructors

LoginProviders({String? loginProviderId, String? providerType, String? providerName, String? providerDisplayName, String? logoUri, bool? enableForgetPassword, bool? enableRegister, ClassicalConfig? classicalConfig})
LoginProviders.fromJson(Map<String, dynamic> json)

Properties

classicalConfig ClassicalConfig?
getter/setter pair
enableForgetPassword bool?
getter/setter pair
enableRegister bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loginProviderId String?
getter/setter pair
logoUri String?
getter/setter pair
providerDisplayName String?
getter/setter pair
providerName String?
getter/setter pair
providerType String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited