PasswordVariableMetadata class

Constructors

PasswordVariableMetadata({String? id, String? fieldKey, String? fieldType, String? parentFieldKey, String? fieldGroupType, String? matchFieldKey, bool? isUnique, bool? isUsername, bool? isPassword, bool? isMatchEnabled, LocaleText? localeText, Attribute? attribute})
PasswordVariableMetadata.fromJson(Map<String, dynamic> json)

Properties

attribute Attribute?
getter/setter pair
fieldGroupType String?
getter/setter pair
fieldKey String?
getter/setter pair
fieldType String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
isMatchEnabled bool?
getter/setter pair
isPassword bool?
getter/setter pair
isUnique bool?
getter/setter pair
isUsername bool?
getter/setter pair
localeText LocaleText?
getter/setter pair
matchFieldKey String?
getter/setter pair
parentFieldKey String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited