Settings class

Constructors

Settings({bool? showRegisterOption, bool? showForgotPassword, bool? showPasswordLessLogin, bool? showRememberMe, bool? showFederationLogin})
Settings.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showFederationLogin bool?
getter/setter pair
showForgotPassword bool?
getter/setter pair
showPasswordLessLogin bool?
getter/setter pair
showRegisterOption bool?
getter/setter pair
showRememberMe bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited