Validation class
Constructors
-
Validation({String? validationKey, List<
ValidationRule> ? validationRule, String? sId, String? id}) -
Validation.fromJson(Map<
String, dynamic> json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sId ↔ String?
-
getter/setter pair
- validationKey ↔ String?
-
getter/setter pair
-
validationRule
↔ List<
ValidationRule> ? -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited